BasePlatformInfo class abstract

Implementers

Constructors

BasePlatformInfo({required bool isWeb, bool isDesktop = false, bool isCupertino = false, bool isMaterial = false, bool isLinux = false, bool isAndroid = false, bool isIOS = false, bool isMacOS = false, bool isWindows = false, bool isMobile = false})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
isAndroid bool
final
isCupertino bool
final
isDesktop bool
final
isIOS bool
final
isLinux bool
final
isMacOS bool
final
isMaterial bool
final
isMobile bool
final
isWeb bool
final
isWindows bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited